///////////////////////////////////////////////////////////////////////
// ADSmartIO.cpp
// 720020-1153x
//
// Applied Data Systems
// www.applieddata.net
//
// Description
// -----------
// This helper class wraps the ADSmartIO functions
//
// History
// -------
// 720020-11531 - July 3, 2003 : ctacke
//   - Initial release
///////////////////////////////////////////////////////////////////////

#include <windows.h>
#include "adsmartio.h"

ADSmartIO::ADSmartIO()
{
	hSmartIO	= NULL;
	loaded		= FALSE;

	RETAILMSG(TRUE,(L"\r\nLoading SMARTIO.DLL...\r\n"));
	hSmartIO = LoadLibrary((L"SMARTIO.dll"));

	if(hSmartIO == NULL)
	{	
		RETAILMSG(TRUE,(L"\r\nCan't find SMARTIO.DLL\r\n"));
		RETAILMSG(TRUE,(L"\r\nLoading KEYBDDR.DLL...\r\n"));
		hSmartIO = LoadLibrary((L"KEYBDDR.dll"));

		if(hSmartIO == NULL)
		{	
			RETAILMSG(TRUE,(L"\r\nFailed to load ADSmartIO library!\r\n"));
			return;
		}
		else
		{	
			RETAILMSG(TRUE,(L"\r\nKEYBDDR.DLL Loaded successfully...\r\n"));
		}
	}
	else
	{	
		RETAILMSG(TRUE,(L"\r\nSMARTIO.DLL Loaded successfully...\r\n"));
	}

	if(hSmartIO!=NULL)
	{	
		DEBUGMSG(TRUE,(_T("Loading ADSmartIO functions  ")));

		SIOSelectOption = (SIOSELECTOPTION)	GetProcAddress(hSmartIO,(L"SIOSelectOption"));
		SIOInitDDRA		= (SIOINITDDRA)		GetProcAddress(hSmartIO,(L"SIOInitDDRA"));
		SIOInitDDRB		= (SIOINITDDRB)		GetProcAddress(hSmartIO,(L"SIOInitDDRB"));
		SIOInitDDRC		= (SIOINITDDRC)		GetProcAddress(hSmartIO,(L"SIOInitDDRC"));
		SIOInitDDRD		= (SIOINITDDRD)		GetProcAddress(hSmartIO,(L"SIOInitDDRD"));
		SIOReadPortA	= (SIOREADPORTA)	GetProcAddress(hSmartIO,(L"SIOReadPortA"));
		SIOReadPortB	= (SIOREADPORTB)	GetProcAddress(hSmartIO,(L"SIOReadPortB"));
		SIOReadPortC	= (SIOREADPORTC)	GetProcAddress(hSmartIO,(L"SIOReadPortC"));
		SIOReadPortD	= (SIOREADPORTD)	GetProcAddress(hSmartIO,(L"SIOReadPortD"));
		SIOWritePortA	= (SIOWRITEPORTA)	GetProcAddress(hSmartIO,(L"SIOWritePortA"));
		SIOWritePortB	= (SIOWRITEPORTB)	GetProcAddress(hSmartIO,(L"SIOWritePortB"));
		SIOWritePortC	= (SIOWRITEPORTC)	GetProcAddress(hSmartIO,(L"SIOWritePortC"));
		SIOWritePortD	= (SIOWRITEPORTD)	GetProcAddress(hSmartIO,(L"SIOWritePortD"));
		
		SIOReadKeypad = (SIOREADKEYPAD)GetProcAddress(hSmartIO,(L"SIOReadKeypad"));
		SIOSetKeyPadSize = (SIOSETKEYPADSIZE)GetProcAddress(hSmartIO,(L"SIOSetKeyPadSize"));
		SIOAnalogConversion = (SIOANALOGCONVERSION)GetProcAddress(hSmartIO,(L"SIOAnalogConversion"));
		SIOFirmwareVersion = (SIOFIRMWAREVERSION)GetProcAddress(hSmartIO,(L"SIOFirmwareVersion"));
		SIOReadDeviceVersion = (SIOREADDEVICEVERSION)GetProcAddress(hSmartIO,(L"SIOReadDeviceVersion"));
		SIOReadDevicePartType = (SIOREADDEVICEPARTTYPE)GetProcAddress(hSmartIO,(L"SIOReadDevicePartType"));
		DEBUGMSG(TRUE,(_T(".")));

		DEBUGMSG(TRUE,(_T("  ok\r\n")));
	}

	loaded = TRUE;

	return;
}

ADSmartIO::~ADSmartIO()
{
	if(hSmartIO)
	{
		FreeLibrary(hSmartIO);
	}
}

UINT ADSmartIO::AnalogConversion (BYTE channel)
{
	if(loaded)
		return SIOAnalogConversion(channel);
	else
		return 0xFFFF;
}

UINT ADSmartIO::FirmwareVersion()
{
	if(loaded)
		return SIOFirmwareVersion();
	else
		return 0xFFFF;
}

void ADSmartIO::InitDDRA(BYTE mask)
{
	if(loaded)
		SIOInitDDRA(mask);
}

void ADSmartIO::InitDDRB(BYTE mask)
{
	if(loaded)
		SIOInitDDRB(mask);
}

void ADSmartIO::InitDDRC(BYTE mask)
{
	if(loaded)
		SIOInitDDRC(mask);
}

void ADSmartIO::InitDDRD(BYTE mask)
{
	if(loaded)
		SIOInitDDRD(mask);
}

UINT ADSmartIO::PartType()
{
	if(loaded)
		return SIOReadDevicePartType();
	else
		return 0xFFFF;
}

UINT ADSmartIO::ReadEEPROM(BYTE blockNumber, BYTE dataBytes[16])
{
	if(loaded)
		return SIOReadEEPROM(blockNumber, dataBytes);
	else
		return 0xFFFF;
}

BYTE ADSmartIO::ReadKeypad()
{
	if(loaded)
		return SIOReadKeypad();
	else
		return 0xFF;
}

BYTE ADSmartIO::ReadPortA()
{
	if(loaded)
		return SIOReadPortA();
	else
		return 0xFF;
}

BYTE ADSmartIO::ReadPortB()
{
	if(loaded)
		return SIOReadPortB();
	else
		return 0xFF;
}

BYTE ADSmartIO::ReadPortC()
{
	if(loaded)
		return SIOReadPortC();
	else
		return 0xFF;
}

BYTE ADSmartIO::ReadPortD()
{
	if(loaded)
		return SIOReadPortD();
	else
		return 0xFF;
}

void ADSmartIO::SelectOption(BYTE option)
{
	if(loaded)
		SIOSelectOption(option);
}

void ADSmartIO::SetBacklightPwm(BYTE value)
{
	if(loaded)
		SIOBackLightPwm(value);
}

void ADSmartIO::SetBacklightState(BOOL value)
{
	if(loaded)
	{
		if(value)
			SIOBackLightON();
		else
			SIOBackLightOFF();
	}
}

void ADSmartIO::SetBacklightVEE(BYTE value)
{
	if(loaded)
		SIOBackLightVEEPwm(value);
}

BOOL ADSmartIO::SetKeyPadSize(BYTE x, BYTE y)
{
	if(loaded)
		return SIOSetKeyPadSize(x, y);
	else
		return FALSE;
}

BOOL ADSmartIO::SetSSPTimeout(ULONG timeout)
{
	if(loaded)
		return SIOSetSSPTimeout(timeout);
	else
		return FALSE;
}